﻿using System;
using System.Web.UI;
using System.Collections.ObjectModel;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WebEdition;

public partial class _Default : System.Web.UI.Page 
{
    protected void Page_Load(object sender, EventArgs e)
    {
        if (!Page.IsPostBack)
        {
            Map1.MapUnit = GeographyUnit.DecimalDegree;

            ShapeFileFeatureLayer lineLayer = new ShapeFileFeatureLayer(MapPath("~/app_data/LineShapes.shp"), ShapeFileReadWriteMode.ReadWrite);
            lineLayer.ZoomLevelSet.ZoomLevel01.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.StandardColors.Green, 4, true);
            lineLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            Map1.StaticOverlay.Layers.Add("Line", lineLayer);

            Map1.EditOverlay.FeatureSource.Open();
            Map1.EditOverlay.Columns.Add(new FeatureSourceColumn("A"));
            Map1.EditOverlay.FeatureSource.Close();
            Map1.EditOverlay.Style.OutlineWidth = 2;

            lineLayer.Open();
            Map1.CurrentExtent = lineLayer.GetBoundingBox();
            lineLayer.Close();
        }
    }

    protected void SubmitClick(object sender, EventArgs args)
    {
        ShapeFileFeatureLayer lineLayer = (ShapeFileFeatureLayer)Map1.StaticOverlay.Layers["Line"];

        foreach (Feature feature in Map1.EditOverlay.Features)
        {
            lineLayer.Open();
            Feature selectedFeature = lineLayer.FeatureSource.GetFeatureById(feature.Id, ReturningColumnsType.AllColumns);

            lineLayer.EditTools.BeginTransaction();
            if (selectedFeature == null)
            {
                lineLayer.EditTools.Add(feature);
            }
            else
            {
                lineLayer.EditTools.Update(feature);
            }

            lineLayer.EditTools.CommitTransaction();
            lineLayer.Close();
        }

        Map1.EditOverlay.Features.Clear();
        Map1.StaticOverlay.Layers["Line"].IsVisible = true;
        Map1.StaticOverlay.Redraw();
    }

    protected void EditClick(object sender, EventArgs args)
    {
        ShapeFileFeatureLayer lineLayer = (ShapeFileFeatureLayer)Map1.StaticOverlay.Layers["Line"];

        lineLayer.Open();
        Collection<Feature> features = lineLayer.QueryTools.GetAllFeatures(ReturningColumnsType.AllColumns);
        lineLayer.Close();

        Map1.EditOverlay.FeatureSource.Open();
        Map1.EditOverlay.Features.Clear();
        foreach (Feature feature in features)
        {
            Map1.EditOverlay.Features.Add(feature);
        }
        Map1.EditOverlay.FeatureSource.Close();

        lineLayer.IsVisible = false;
        Map1.StaticOverlay.Redraw();
        Map1.EditOverlay.TrackMode = TrackMode.Edit;
    }
}
